@@ -1,5 +1,7 @@
+pub mod close;
 pub mod init;
 pub mod pay;
 
+pub use close::*;
 pub use init::*;
 pub use pay::*;
